@@ -505,6 +505,12 @@ class Plotter:
         else:
             return "best"
 
+    def get_legend_nb_col(self, to_plot):
+        if "legend_nb_col" in to_plot:
+            return to_plot["legend_nb_col"]
+        else:
+            return 1
+
     def add_legend(self, to_plot, axe):
         """Add a legend to the figure.
 
@@ -514,8 +520,12 @@ class Plotter:
         """
         if "legend" in to_plot:
             fontsize = self.get_legend_fontsize(to_plot)
+            nb_col = self.get_legend_nb_col(to_plot)
             loc = self.get_legend_location(to_plot)
-            axe.legend(to_plot["legend"], prop={"size": fontsize}, loc=loc)
+            if type(loc) is str:
+                axe.legend(to_plot["legend"], prop={"size": fontsize}, loc=loc, ncol=nb_col)
+            elif type(loc) is tuple:
+                axe.legend(to_plot["legend"], prop={"size": fontsize}, bbox_to_anchor=loc, ncol=nb_col)
 
     def get_labels_fontsize(self, to_plot):
         if "labels_fontsize" in to_plot:
@@ -679,6 +689,11 @@ class Plotter:
         axe - the subfigure where to work on.
 
         """
+        data = None
+        if type(to_plot["data"]) is list:
+            data = to_plot["data"][0]
+        else:
+            data = to_plot["data"]
         x_coef = 1
         y_coef = 1
         if "image" in to_plot:
@@ -687,8 +702,8 @@ class Plotter:
                 if to_plot["scale_to_image"]:
                     img_width = img_shape[1]
                     img_height = img_shape[0]
-                    mat_width = to_plot["data"].shape[1]-1
-                    mat_height = to_plot["data"].shape[0]-1
+                    mat_width = data.shape[1]-1
+                    mat_height = data.shape[0]-1
                     x_coef = img_width/mat_width
                     y_coef = img_height/mat_height
                 if "x_scale" in to_plot:
@@ -815,7 +830,7 @@ class Plotter:
             data = self.matrix_to_binary_scatter(data_to_plot)
             x_data = [d*x_coef for d in data[1]]
             y_data = [d*y_coef for d in data[0]]
-            scat = axe.scatter(x_data, y_data, opacity=opacity)
+            scat = axe.scatter(x_data, y_data, alpha=opacity)
 
     def plot_data(self):
         """Plot the data from the to_plot parameter.
